@@ -1,5 +1,5 @@
 package Net::Google::Analytics::Request;
-$Net::Google::Analytics::Request::VERSION = '3.03';
+$Net::Google::Analytics::Request::VERSION = '3.04';
 use strict;
 use warnings;
 
@@ -16,24 +16,26 @@ use Class::XSAccessor
         segment
         start_index max_results
         fields
+        sampling_level
         pretty_print
         user_ip quota_user
     ) ],
     constructor => 'new';
 
 my @param_map = (
-    ids          => 'ids',
-    start_date   => 'start-date',
-    end_date     => 'end-date',
-    metrics      => 'metrics',
-    dimensions   => 'dimensions',
-    sort         => 'sort',
-    filters      => 'filters',
-    segment      => 'segment',
-    fields       => 'fields',
-    pretty_print => 'prettyPrint',
-    user_ip      => 'userIp',
-    quota_user   => 'quotaUser',
+    ids            => 'ids',
+    start_date     => 'start-date',
+    end_date       => 'end-date',
+    metrics        => 'metrics',
+    dimensions     => 'dimensions',
+    sort           => 'sort',
+    filters        => 'filters',
+    segment        => 'segment',
+    fields         => 'fields',
+    sampling_level => 'samplingLevel',
+    pretty_print   => 'prettyPrint',
+    user_ip        => 'userIp',
+    quota_user     => 'quotaUser',
 );
 
 sub _params {
@@ -78,7 +80,7 @@ Net::Google::Analytics::Request - Google Analytics API request
 
 =head1 VERSION
 
-version 3.03
+version 3.04
 
 =head1 SYNOPSIS
 
@@ -147,6 +149,8 @@ Required
 
 =head2 segment
 
+=head2 sampling_level
+
 =head2 start_index
 
 =head2 max_results
